\name{generate.toydata}
\alias{generate.toydata}
\title{
Generation and analysis of synthetic data in stochastic profiling model
}
\description{
Generation of a dataset of 500 i.i.d measurements as considered in the stochastic profiling model. Afterwards estimation of the model parameters and comparison of the estimates with the true value.
}
\usage{
generate.toydata(model = "LN-LN")
}
\arguments{
  \item{model}{
the chosen stochastic profiling model: "LN-LN", "rLN-LN" or "EXP-LN"
}
}
\details{
This function first generates a dataset of 500 i.i.d. 10-cell samplings as considered in the stochastic profiling models "LN-LN", "rLN-LN" and "EXP-LN". The employed parameters are TY=2 (i.e. two different types of cells are assumed) and p=c(0.2,0.8) for all models. Furthermore, mu=c(1.5,-1.5) and sigma=0.2 for the LN-LN model, mu=c(1.5,-1.5) and sigma=(0.2,0.6) for the rLN-LN model, and mu=1.5, sigma=0.2 and lambda=0.5 for the EXP-LN model. The generated data is displayed in a histogram together with the theoretical probability density function. At the end of the estimation procedure, the profile log-likelihood plots are shown. Finally, the true and the estimated probability density functions are compared and the estimation results are printed.
}
\value{
A list as returned by \code{stochprof.loop}, i.e. the following four components:
\item{mle}{maximum likelihood estimate}
\item{loglikeli}{value of the log-likelihood function at maximum likelihood estimate}
\item{ci}{approximate marginal maximum likelihood confidence intervals for the maximum likelihood estimate}
\item{pargrid}{matrix containing parameter combinations and according values of the target function}
}
\references{
"Parameterizing cell-to-cell regulatory heterogeneities via stochastic transcriptional profiles" by Sameer S Bajikar*, Christiane Fuchs*, Andreas Roller, Fabian J Theis^ and Kevin A Janes^: PNAS 2014, 111(5), E626-635 (* joint first authors, ^ joint last authors)
}
\author{
Christiane Fuchs

Maintainer: Christiane Fuchs <christiane.fuchs@helmholtz-muenchen.de>
}
\note{
Executing this function as it is (i.e. without any parallelization and with the default model "LN-LN") takes approx. 2-3 minutes on a standard computer. Estimation for the "rLN-LN" and "EXP-LN" model takes longer.
}
\keyword{ stochastic profiling }
\keyword{ synthetic data }
