\name{stochprofML-package}
\alias{stochprofML-package}
\alias{stochprofML}
\docType{package}
\title{
Stochastic Profiling using Maximum Likelihood Estimation
}
\description{
This is an R package accompanying the paper "Parameterizing cell-to-cell regulatory heterogeneities via stochastic transcriptional profiles" by Sameer S Bajikar, Christiane Fuchs, Andreas Roller, Fabian J Theis and Kevin A Janes (PNAS 2014, 111(5), E626-635). In this paper, we measure expression profiles from small heterogeneous populations of cells. Each cell is assumed to be from a mixture of lognormal and exponential distributions (see details). We perform maximum likelihood estimation in order to infer the mixture ratio and the parameters of the lognormal/exponential distributions from the cumulated expression measurements.
}
\details{
\tabular{ll}{
Package: \tab stochprofML\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2014-05-22\cr
License: \tab GPL (>= 2)\cr
}
There are three stochastic profiling models: The lognormal-lognormal (LN-LN) model assumes that each cell is from a mixture of one or more lognormal distributions with different log-means but identical log-standard deviations. In the relaxed lognormal-lognormal (rLN-LN) model, the log-standard deviations are not necessarily identical. The exponential-lognormal (EXP-LN) model considers the mixture of zero, one or more lognormal distributions and one exponential distribution.

Parameters can be estimated calling \code{stochprof.loop}, which again utilizes three other functions: \code{stochprof.search.LNLN}/ \code{stochprof.search.rLNLN}/ \code{stochprof.search.EXPLN} in order to calculate and locally optimize the likelihood function; \code{stochprof.results.LNLN}/ \cr \code{stochprof.results.rLNLN}/ \code{stochprof.results.EXPLN} for evaluating these results; and \cr \code{calculate.ci.LNLN}/ \code{calculate.ci.rLNLN}/ \code{calculate.ci.EXPLN} for calculating confidence intervals.

Two essential functions are \code{r.sum.of.mixtures.LNLN}/ \code{r.sum.of.mixtures.rLNLN}/ \cr \code{r.sum.of.mixtures.EXPLN} and \code{d.sum.of.mixtures.LNLN}/ \code{d.sum.of.mixtures.rLNLN}/ \cr \code{d.sum.of.mixtures.EXPLN} for the density and random number generation of the distribution assumed for all measurements in the stochastic profiling model. 

The package provides four datasets: \code{sod2}, containing real measurements for one gene, and \cr \code{toycluster.LNLN}/ \code{toycluster.rLNLN}/ \code{toycluster.EXPLN}, containing artificial data for 12 genes generated with the three stochastic profiling models.

Three examples for typical analyses are given below.
}
\author{
Christiane Fuchs

Maintainer: Christiane Fuchs <christiane.fuchs@helmholtz-muenchen.de>
}
\references{
"Parameterizing cell-to-cell regulatory heterogeneities via stochastic transcriptional profiles" by Sameer S Bajikar*, Christiane Fuchs*, Andreas Roller, Fabian J Theis^ and Kevin A Janes^: PNAS 2014, 111(5), E626-635 (* joint first authors, ^ joint last authors)
}
\keyword{ package }
\keyword{ stochastic profiling }
\examples{
\dontrun{
# Generate a synthetic dataset (without measurement error) for one gene 
# and estimate the parameters from this data.
generate.toydata()

# Estimate the model parameters for the SOD2 dataset.
analyze.sod2()

# Estimate the model parameters for the 12-gene toycluster.
analyze.toycluster()
}
}
